summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/editor.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /lib/koproperty/editor.cpp
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'lib/koproperty/editor.cpp')
-rw-r--r--lib/koproperty/editor.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/lib/koproperty/editor.cpp b/lib/koproperty/editor.cpp
index 7f8bb11a..7040e885 100644
--- a/lib/koproperty/editor.cpp
+++ b/lib/koproperty/editor.cpp
@@ -233,7 +233,7 @@ Editor::fill()
}
}
-// tqrepaint();
+// repaint();
if (firstChild())
{
@@ -271,12 +271,12 @@ Editor::addItem(const TQCString &name, EditorItem *parent)
// Create child items
item->setOpen(true);
- if(!property->tqchildren())
+ if(!property->children())
return;
last = 0;
- TQValueList<Property*>::ConstIterator endIt = property->tqchildren()->constEnd();
- for(TQValueList<Property*>::ConstIterator it = property->tqchildren()->constBegin(); it != endIt; ++it) {
+ TQValueList<Property*>::ConstIterator endIt = property->children()->constEnd();
+ for(TQValueList<Property*>::ConstIterator it = property->children()->constBegin(); it != endIt; ++it) {
//! \todo allow to have child prop with child items too
if( *it && (*it)->isVisible() )
last = new EditorItem(this, item, *it, last);
@@ -652,7 +652,7 @@ Editor::createWidgetForProperty(Property *property, bool changeWidgetProperty)
this, TQT_SLOT(slotWidgetRejectInput(Widget*)) );
}
//update tqgeometry earlier, because Widget::setValue() can depend on widget's tqgeometry
updateEditorGeometry(d->currentItem, widget);
if(widget && (!widget->property() || changeWidgetProperty))
@@ -723,7 +723,7 @@ Editor::updateGroupLabelsPosition()
TQRect r = itemRect((TQListViewItem*) group);
if(group->label()) {
group->label()->setGeometry(r);
- group->label()->tqrepaint();
+ group->label()->repaint();
}
group = dynamic_cast<EditorGroupItem*>(group->nextSibling());
}
@@ -748,7 +748,7 @@ Editor::showUndoButton( bool show )
return;
int y = viewportToContents(TQPoint(0, itemRect(d->currentItem).y())).y();
- TQRect tqgeometry(columnWidth(0), y, columnWidth(1) + 1, d->currentItem->height());
+ TQRect geometry(columnWidth(0), y, columnWidth(1) + 1, d->currentItem->height());
d->undoButton->resize(d->baseRowHeight, d->currentItem->height());
updateEditorGeometry(true, show);
@@ -756,21 +756,21 @@ Editor::showUndoButton( bool show )
if (!show) {
/* if (d->currentWidget) {
if (d->currentWidget->leavesTheSpaceForRevertButton()) {
- tqgeometry.setWidth(tqgeometry.width()-d->undoButton->width());
+ geometry.setWidth(geometry.width()-d->undoButton->width());
}
- d->currentWidget->resize(tqgeometry.width(), tqgeometry.height());
+ d->currentWidget->resize(geometry.width(), geometry.height());
}*/
d->undoButton->hide();
return;
}
- TQPoint p = contentsToViewport(TQPoint(0, tqgeometry.y()));
- d->undoButton->move(tqgeometry.x() + tqgeometry.width()
+ TQPoint p = contentsToViewport(TQPoint(0, geometry.y()));
+ d->undoButton->move(geometry.x() + geometry.width()
-((d->currentWidget && d->currentWidget->hasBorders())?1:0)/*editor is moved by 1 to left*/
- d->undoButton->width(), p.y());
// if (d->currentWidget) {
// d->currentWidget->move(d->currentWidget->x(), p.y());
-// d->currentWidget->resize(tqgeometry.width()-d->undoButton->width(), tqgeometry.height());
+// d->currentWidget->resize(geometry.width()-d->undoButton->width(), geometry.height());
// }
d->undoButton->show();
}
@@ -791,7 +791,7 @@ Editor::slotExpanded(TQListViewItem *item)
updateEditorGeometry();
updateGroupLabelsPosition();
repaintContents();
- tqrepaint();
+ repaint();
}
void
@@ -815,7 +815,7 @@ Editor::slotCollapsed(TQListViewItem *item)
updateEditorGeometry();
updateGroupLabelsPosition();
repaintContents();
- tqrepaint();
+ repaint();
}
void
@@ -826,7 +826,7 @@ Editor::slotColumnSizeChanged(int section, int oldSize, int newSize)
Q_UNUSED(newSize);
/*for (TQListViewItemIterator it(this); it.current(); ++it) {
if (section == 0 && dynamic_cast<EditorGroupItem*>(it.current())) {
- it.current()->tqrepaint();
+ it.current()->repaint();
}
}*/
/*
@@ -843,7 +843,7 @@ Editor::slotColumnSizeChanged(int section, int oldSize, int newSize)
}
}*/
// repaintContents();
-// tqrepaint();
+// repaint();
updateEditorGeometry();
update();
}
@@ -1021,7 +1021,7 @@ Editor::setSorting( int column, bool ascending )
updateEditorGeometry();
updateGroupLabelsPosition();
repaintContents();
- tqrepaint();
+ repaint();
}
#include "editor.moc"
@@ -652,7 +652,7 @@ Editor::createWidgetForProperty(Property *property, bool changeWidgetProperty)
this, TQT_SLOT(slotWidgetRejectInput(Widget*)) );
}
- //update tqgeometry earlier, because Widget::setValue() can depend on widget's tqgeometry
+ //update geometry earlier, because Widget::setValue() can depend on widget's geometry
updateEditorGeometry(d->currentItem, widget);
if(widget && (!widget->property() || changeWidgetProperty))